# PyGuards

[![Pipeline Status](https://gitlab.com/MathiusD/pyguards/badges/master/pipeline.svg)](https://gitlab.com/MathiusD/pyguards/-/pipelines)
[![Coverage Report](https://gitlab.com/MathiusD/pyguards/badges/master/coverage.svg)](https://mathiusd.gitlab.io/pyguards/reports/coverage)
[Mutation Report](https://mathiusd.gitlab.io/pyguards/reports/mutation)

Checks and Guards for Python
